disp(' ')
disp(' psd_to_sine.m   ver 1.0   October 2, 2013')
disp(' by Tom Irvine   Email: tom@vibrationdata.com')
disp(' ')
disp(' This program calculates an equivalent sine tone for a PSD base ');
disp(' input in terms of fatigue damage. The test item is assumed to be');
disp(' a single-degree-of-freedom system. ');
disp(' ')
disp(' The power spectral density may vary arbitrarily with frequency. ')
disp(' The input file must have two columns: frequency(Hz) & accel(G^2/Hz)')
disp(' ')
%
close all;
%
clear f;
clear a;
clear a_vrs;
clear trans;
clear s;
clear damp;
clear THF;
%
fig_num=1;
%
disp(' Select file input method       ');
disp('   1=external ASCII file        ');
disp('   2=file preloaded into Matlab ');
disp('   3=library function           ');
file_choice = input('');
%
if(file_choice==1)
    [filename, pathname] = uigetfile('*.*');
    filename = fullfile(pathname, filename);
    fid = fopen(filename,'r');
    THF = fscanf(fid,'%g %g',[2 inf]);
    THF=THF';
end
if(file_choice==2)
    THF = input(' Enter the matrix name:  ');
end
if(file_choice==1 || file_choice==2)
    size(THF);
    f=THF(:,1);
    a=THF(:,2);
end
%
if(file_choice==3)
%
   [f,a]=PSD_library();
%
end
%
MAX = 5000;
tpi=2.*pi;
%
disp(' ');
natural_frequency=input(' Enter the natural frequency (Hz)  ');
%
disp(' ');
Q=input(' Enter the amplification factor (typically Q=10) ');
damp=1/(2*Q);
%
disp(' ');
alpha=input(' Enter alpha (typically 2.0) ' );
%
n=length(f);
%
[s,grms]=calculate_PSD_slopes(f,a);
out5 = sprintf('\n Input PSD Overall Level = %10.3f ',grms);
disp(out5);
%
df=1.;
%
[fi,ai]=interpolate_PSD(f,a,s,df);
%
[a_vrs,rd_vrs,trans,opsd]=sdof_ran_engine(fi,ai,damp,df,natural_frequency);
%
disp(' ')
disp(' SDOF Acceleration Response ')
disp(' ')
out1=sprintf('     = %8.3g GRMS',a_vrs);
out2=sprintf('     = %8.3g G 3-sigma',3.*a_vrs);
disp(out1);
disp(out2);
%
omegan=tpi*natural_frequency;
%
fi=fix_size(fi);
opsd=fix_size(opsd);
a=fix_size(ai);
trans=fix_size(trans);
%
ppp=[fi opsd];
qqq=[fi a];
%
clear response_psd;
clear power_trans;
%
response_psd=[fi a];
power_trans=[fi trans];
%
leg_a=sprintf('Response %5.3g GRMS',a_vrs);
leg_b=sprintf('Input %5.3g GRMS',grms);
%              
x_label=sprintf(' Frequency (Hz)');
y_label=sprintf(' Accel (G^2/Hz)'); 
t_string = sprintf(' Power Spectral Density   fn=%g Hz  Q=%g  ',natural_frequency,Q);   
%
[fig_num]=plot_PSD_two_sdof_ran(fig_num,x_label,y_label,t_string,ppp,qqq,leg_a,leg_b); 
%
S=alpha*a_vrs/Q;
%
out1=sprintf('\n Equivalent sine input = %8.4g G at %g Hz',S,natural_frequency);
disp(out1);
